import { scene, engine } from './scene'
import { AssetsManager } from "@babylonjs/core/Misc/assetsManager";
import { Hud } from "./gui/Hud";
import { ArcRotateCamera } from '@babylonjs/core/Cameras/arcRotateCamera';
import { Vector3 } from '@babylonjs/core/Maths/math.vector';

async function main(): Promise<void> {
    const assetsManager = new AssetsManager(scene);
    assetsManager.useDefaultLoadingScreen = false

    const alpha = Math.PI / 4
    const beta = Math.PI / 3
    const radius = 30
    const target = new Vector3(0, 0, 0)

    new ArcRotateCamera(
        'Camera',
        alpha,
        beta,
        radius,
        target,
        scene
    )

    const hud = new Hud(engine, scene, assetsManager)

    assetsManager.load()

    engine.runRenderLoop(() => {
        scene.render()
    })

    window.addEventListener('resize', () => {
        engine.resize()
    })
}

main();